# AnalysisResultResponseResultPythonpackages

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**location** | **str** | A location where the Python package is installed |
**package_name** | **str** | Python package name |
**package_version** | **str** | Python package version |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

